==> pystan-2.11.0.0.zip: pystan-2.11.0.0/pystan/stan/lib/stan_math_2.11.0/doc/api/html/search/functions_1.js <==
var searchData=
[
  ['bernoulli_5fccdf_5flog',['bernoulli_ccdf_log',['../namespacestan_1_1math.html#a9d8811804a3bb9a9cd943422ce3938db',1,'stan::math']]],
  ['bernoulli_5fcdf',['bernoulli_cdf',['../namespacestan_1_1math.html#a0b80aeaa1cc10d315d915aba2ddc6180',1,'stan::math']]],
  ['bernoulli_5fcdf_5flog',['bernoulli_cdf_log',['../namespacestan_1_1math.html#ac569e9e067f4d61280974e9a54ac6476',1,'stan::math']]],
  ['bernoulli_5flog',['bernoulli_log',['../namespacestan_1_1math.html#a3e360bb277db7a3318c1c368dbccdda8',1,'stan::math::bernoulli_log(const T_n &amp;n, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a075f08b1d99b150b64d851139be35894',1,'stan::math::bernoulli_log(const T_y &amp;n, const T_prob &amp;theta)']]],
  ['bernoulli_5flogit_5flog',['bernoulli_logit_log',['../namespacestan_1_1math.html#aa9048a0a4bd452c7e797cb5a496b0b97',1,'stan::math::bernoulli_logit_log(const T_n &amp;n, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a193781437c0aa1a48fe48b24d9ae8130',1,'stan::math::bernoulli_logit_log(const T_n &amp;n, const T_prob &amp;theta)']]],
  ['bernoulli_5frng',['bernoulli_rng',['../namespacestan_1_1math.html#ac46d3934578fb7346a900677a3e8c377',1,'stan::math']]],
  ['bessel_5ffirst_5fkind',['bessel_first_kind',['../namespacestan_1_1math.html#a0f08e25e46df323a2429edc45d1c8954',1,'stan::math::bessel_first_kind(int v, const fvar&lt; T &gt; &amp;z)'],['../namespacestan_1_1math.html#aebfb3835848bd8550192cd5e090d3b5a',1,'stan::math::bessel_first_kind(const int v, const T2 z)'],['../namespacestan_1_1math.html#a367822396d06842610b32ec1d1010944',1,'stan::math::bessel_first_kind(const int &amp;v, const var &amp;a)']]],
  ['bessel_5fsecond_5fkind',['bessel_second_kind',['../namespacestan_1_1math.html#ab0b227eac2dd4cbc55462ecebe940294',1,'stan::math::bessel_second_kind(int v, const fvar&lt; T &gt; &amp;z)'],['../namespacestan_1_1math.html#a645ce13c6454913ec39be807751604dc',1,'stan::math::bessel_second_kind(const int v, const T2 z)'],['../namespacestan_1_1math.html#a7bff905107813b205e8cf81ace301ef9',1,'stan::math::bessel_second_kind(const int &amp;v, const var &amp;a)']]],
  ['beta_5fbinomial_5fccdf_5flog',['beta_binomial_ccdf_log',['../namespacestan_1_1math.html#ab380fecf1c6c99b602f212cbccc28a83',1,'stan::math']]],
  ['beta_5fbinomial_5fcdf',['beta_binomial_cdf',['../namespacestan_1_1math.html#a6abc35510e01a52b5138a19bfedb2a3e',1,'stan::math']]],
  ['beta_5fbinomial_5fcdf_5flog',['beta_binomial_cdf_log',['../namespacestan_1_1math.html#adf2c63ba04c87c46bcb0db999d955e9b',1,'stan::math']]],
  ['beta_5fbinomial_5flog',['beta_binomial_log',['../namespacestan_1_1math.html#a5c2462b112bf6512c4db7c6abea6478c',1,'stan::math::beta_binomial_log(const T_n &amp;n, const T_N &amp;N, const T_size1 &amp;alpha, const T_size2 &amp;beta)'],['../namespacestan_1_1math.html#a48a71d6f54236310fba1a94b445272f3',1,'stan::math::beta_binomial_log(const T_n &amp;n, const T_N &amp;N, const T_size1 &amp;alpha, const T_size2 &amp;beta)']]],
  ['beta_5fbinomial_5frng',['beta_binomial_rng',['../namespacestan_1_1math.html#ac0443ac7dbd959b40b1a958767857f5e',1,'stan::math']]],
  ['beta_5fccdf_5flog',['beta_ccdf_log',['../namespacestan_1_1math.html#a625d31cf8da1c8cd2ea99af113ed6fe6',1,'stan::math']]],
  ['beta_5fcdf',['beta_cdf',['../namespacestan_1_1math.html#a84beaaff122d602406a515a9dd97bb90',1,'stan::math']]],
  ['beta_5fcdf_5flog',['beta_cdf_log',['../namespacestan_1_1math.html#afa87400b4ecd4bba0d10158cad4f3a8b',1,'stan::math']]],
  ['beta_5flog',['beta_log',['../namespacestan_1_1math.html#a0246a55c1c14d2c7ec35a0070af63299',1,'stan::math::beta_log(const T_y &amp;y, const T_scale_succ &amp;alpha, const T_scale_fail &amp;beta)'],['../namespacestan_1_1math.html#a7e5818c82697944b91b483674b14ad22',1,'stan::math::beta_log(const T_y &amp;y, const T_scale_succ &amp;alpha, const T_scale_fail &amp;beta)']]],
  ['beta_5frng',['beta_rng',['../namespacestan_1_1math.html#a7fa2015614535f45c2cb6d5f544643d0',1,'stan::math']]],
  ['binary_5flog_5floss',['binary_log_loss',['../namespacestan_1_1math.html#ae0d069b5730083b0203812d63c6f62f3',1,'stan::math::binary_log_loss(const int y, const fvar&lt; T &gt; &amp;y_hat)'],['../namespacestan_1_1math.html#add2a043f562537b8cc57bb35780ac5b5',1,'stan::math::binary_log_loss(const int y, const T y_hat)'],['../namespacestan_1_1math.html#a87b93caccb44639dea5c47f78fe6be28',1,'stan::math::binary_log_loss(const int y, const stan::math::var &amp;y_hat)']]],
  ['binomial_5fccdf_5flog',['binomial_ccdf_log',['../namespacestan_1_1math.html#a92586706a7afc2c968e0c11a9a021f8a',1,'stan::math']]],
  ['binomial_5fcdf',['binomial_cdf',['../namespacestan_1_1math.html#a25ca53e4f20460de16af84337acba3f0',1,'stan::math']]],
  ['binomial_5fcdf_5flog',['binomial_cdf_log',['../namespacestan_1_1math.html#a96b0617f8ad60887c84b0cd91ebe202e',1,'stan::math']]],
  ['binomial_5fcoefficient_5flog',['binomial_coefficient_log',['../namespacestan_1_1math.html#ab3ae920ef2089bb1686eb51c3dc153b4',1,'stan::math::binomial_coefficient_log(const fvar&lt; T &gt; &amp;x1, const fvar&lt; T &gt; &amp;x2)'],['../namespacestan_1_1math.html#a113b2443c22c0859cc797b7c1bdea59f',1,'stan::math::binomial_coefficient_log(const fvar&lt; T &gt; &amp;x1, const double x2)'],['../namespacestan_1_1math.html#a6d6816ab0a50a160820063ffe087a826',1,'stan::math::binomial_coefficient_log(const double x1, const fvar&lt; T &gt; &amp;x2)'],['../namespacestan_1_1math.html#a27dad23d38c6d5e74c65e7571c70272e',1,'stan::math::binomial_coefficient_log(const T_N N, const T_n n)']]],
  ['binomial_5flog',['binomial_log',['../namespacestan_1_1math.html#a9de035dd17c118b3144a9ed9c867378f',1,'stan::math::binomial_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a8b3409628d97b7ff020f2c0c694d8d40',1,'stan::math::binomial_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;theta)']]],
  ['binomial_5flogit_5flog',['binomial_logit_log',['../namespacestan_1_1math.html#a8f5a9e223a39b11f58fe044dcb2bc7ca',1,'stan::math::binomial_logit_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;alpha)'],['../namespacestan_1_1math.html#a5378254419361dd7a0bfacf139b49401',1,'stan::math::binomial_logit_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;alpha)']]],
  ['binomial_5frng',['binomial_rng',['../namespacestan_1_1math.html#aa41d355d768c2258bf999bc765382f27',1,'stan::math']]],
  ['block',['block',['../namespacestan_1_1math.html#a69be3cf865daa6eca4a859f97ffaa8f7',1,'stan::math']]],
  ['bytes_5fallocated',['bytes_allocated',['../classstan_1_1math_1_1stack__alloc.html#ac72fe7b15ca3086766445e2672e0b504',1,'stan::math::stack_alloc']]]
];

==> pystan-2.12.0.0.zip: pystan-2.12.0.0/pystan/stan/lib/stan_math_2.12.0/doc/api/html/search/functions_1.js <==
var searchData=
[
  ['bernoulli_5fccdf_5flog',['bernoulli_ccdf_log',['../namespacestan_1_1math.html#a9d8811804a3bb9a9cd943422ce3938db',1,'stan::math']]],
  ['bernoulli_5fcdf',['bernoulli_cdf',['../namespacestan_1_1math.html#a0b80aeaa1cc10d315d915aba2ddc6180',1,'stan::math']]],
  ['bernoulli_5fcdf_5flog',['bernoulli_cdf_log',['../namespacestan_1_1math.html#ac569e9e067f4d61280974e9a54ac6476',1,'stan::math']]],
  ['bernoulli_5flog',['bernoulli_log',['../namespacestan_1_1math.html#a3e360bb277db7a3318c1c368dbccdda8',1,'stan::math::bernoulli_log(const T_n &amp;n, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a075f08b1d99b150b64d851139be35894',1,'stan::math::bernoulli_log(const T_y &amp;n, const T_prob &amp;theta)']]],
  ['bernoulli_5flogit_5flog',['bernoulli_logit_log',['../namespacestan_1_1math.html#aa9048a0a4bd452c7e797cb5a496b0b97',1,'stan::math::bernoulli_logit_log(const T_n &amp;n, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a193781437c0aa1a48fe48b24d9ae8130',1,'stan::math::bernoulli_logit_log(const T_n &amp;n, const T_prob &amp;theta)']]],
  ['bernoulli_5frng',['bernoulli_rng',['../namespacestan_1_1math.html#ac46d3934578fb7346a900677a3e8c377',1,'stan::math']]],
  ['bessel_5ffirst_5fkind',['bessel_first_kind',['../namespacestan_1_1math.html#a0f08e25e46df323a2429edc45d1c8954',1,'stan::math::bessel_first_kind(int v, const fvar&lt; T &gt; &amp;z)'],['../namespacestan_1_1math.html#aebfb3835848bd8550192cd5e090d3b5a',1,'stan::math::bessel_first_kind(const int v, const T2 z)'],['../namespacestan_1_1math.html#a672ae58515af44d6b87f2a79c3214643',1,'stan::math::bessel_first_kind(int v, const var &amp;a)']]],
  ['bessel_5fsecond_5fkind',['bessel_second_kind',['../namespacestan_1_1math.html#ab0b227eac2dd4cbc55462ecebe940294',1,'stan::math::bessel_second_kind(int v, const fvar&lt; T &gt; &amp;z)'],['../namespacestan_1_1math.html#a645ce13c6454913ec39be807751604dc',1,'stan::math::bessel_second_kind(const int v, const T2 z)'],['../namespacestan_1_1math.html#a177d5e3051911f4e1026c6b149429f7c',1,'stan::math::bessel_second_kind(int v, const var &amp;a)']]],
  ['beta_5fbinomial_5fccdf_5flog',['beta_binomial_ccdf_log',['../namespacestan_1_1math.html#ab380fecf1c6c99b602f212cbccc28a83',1,'stan::math']]],
  ['beta_5fbinomial_5fcdf',['beta_binomial_cdf',['../namespacestan_1_1math.html#a6abc35510e01a52b5138a19bfedb2a3e',1,'stan::math']]],
  ['beta_5fbinomial_5fcdf_5flog',['beta_binomial_cdf_log',['../namespacestan_1_1math.html#adf2c63ba04c87c46bcb0db999d955e9b',1,'stan::math']]],
  ['beta_5fbinomial_5flog',['beta_binomial_log',['../namespacestan_1_1math.html#a5c2462b112bf6512c4db7c6abea6478c',1,'stan::math::beta_binomial_log(const T_n &amp;n, const T_N &amp;N, const T_size1 &amp;alpha, const T_size2 &amp;beta)'],['../namespacestan_1_1math.html#a48a71d6f54236310fba1a94b445272f3',1,'stan::math::beta_binomial_log(const T_n &amp;n, const T_N &amp;N, const T_size1 &amp;alpha, const T_size2 &amp;beta)']]],
  ['beta_5fbinomial_5frng',['beta_binomial_rng',['../namespacestan_1_1math.html#ac0443ac7dbd959b40b1a958767857f5e',1,'stan::math']]],
  ['beta_5fccdf_5flog',['beta_ccdf_log',['../namespacestan_1_1math.html#a625d31cf8da1c8cd2ea99af113ed6fe6',1,'stan::math']]],
  ['beta_5fcdf',['beta_cdf',['../namespacestan_1_1math.html#a84beaaff122d602406a515a9dd97bb90',1,'stan::math']]],
  ['beta_5fcdf_5flog',['beta_cdf_log',['../namespacestan_1_1math.html#afa87400b4ecd4bba0d10158cad4f3a8b',1,'stan::math']]],
  ['beta_5flog',['beta_log',['../namespacestan_1_1math.html#a0246a55c1c14d2c7ec35a0070af63299',1,'stan::math::beta_log(const T_y &amp;y, const T_scale_succ &amp;alpha, const T_scale_fail &amp;beta)'],['../namespacestan_1_1math.html#a7e5818c82697944b91b483674b14ad22',1,'stan::math::beta_log(const T_y &amp;y, const T_scale_succ &amp;alpha, const T_scale_fail &amp;beta)']]],
  ['beta_5frng',['beta_rng',['../namespacestan_1_1math.html#a7fa2015614535f45c2cb6d5f544643d0',1,'stan::math']]],
  ['binary_5flog_5floss',['binary_log_loss',['../namespacestan_1_1math.html#ae0d069b5730083b0203812d63c6f62f3',1,'stan::math::binary_log_loss(const int y, const fvar&lt; T &gt; &amp;y_hat)'],['../namespacestan_1_1math.html#add2a043f562537b8cc57bb35780ac5b5',1,'stan::math::binary_log_loss(const int y, const T y_hat)'],['../namespacestan_1_1math.html#a11d886f22cb790152dbcae243813d242',1,'stan::math::binary_log_loss(const int y, const var &amp;y_hat)']]],
  ['binomial_5fccdf_5flog',['binomial_ccdf_log',['../namespacestan_1_1math.html#a92586706a7afc2c968e0c11a9a021f8a',1,'stan::math']]],
  ['binomial_5fcdf',['binomial_cdf',['../namespacestan_1_1math.html#a25ca53e4f20460de16af84337acba3f0',1,'stan::math']]],
  ['binomial_5fcdf_5flog',['binomial_cdf_log',['../namespacestan_1_1math.html#a96b0617f8ad60887c84b0cd91ebe202e',1,'stan::math']]],
  ['binomial_5fcoefficient_5flog',['binomial_coefficient_log',['../namespacestan_1_1math.html#ab3ae920ef2089bb1686eb51c3dc153b4',1,'stan::math::binomial_coefficient_log(const fvar&lt; T &gt; &amp;x1, const fvar&lt; T &gt; &amp;x2)'],['../namespacestan_1_1math.html#a113b2443c22c0859cc797b7c1bdea59f',1,'stan::math::binomial_coefficient_log(const fvar&lt; T &gt; &amp;x1, const double x2)'],['../namespacestan_1_1math.html#a6d6816ab0a50a160820063ffe087a826',1,'stan::math::binomial_coefficient_log(const double x1, const fvar&lt; T &gt; &amp;x2)'],['../namespacestan_1_1math.html#a27dad23d38c6d5e74c65e7571c70272e',1,'stan::math::binomial_coefficient_log(const T_N N, const T_n n)']]],
  ['binomial_5flog',['binomial_log',['../namespacestan_1_1math.html#a9de035dd17c118b3144a9ed9c867378f',1,'stan::math::binomial_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;theta)'],['../namespacestan_1_1math.html#a8b3409628d97b7ff020f2c0c694d8d40',1,'stan::math::binomial_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;theta)']]],
  ['binomial_5flogit_5flog',['binomial_logit_log',['../namespacestan_1_1math.html#a8f5a9e223a39b11f58fe044dcb2bc7ca',1,'stan::math::binomial_logit_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;alpha)'],['../namespacestan_1_1math.html#a5378254419361dd7a0bfacf139b49401',1,'stan::math::binomial_logit_log(const T_n &amp;n, const T_N &amp;N, const T_prob &amp;alpha)']]],
  ['binomial_5frng',['binomial_rng',['../namespacestan_1_1math.html#aa41d355d768c2258bf999bc765382f27',1,'stan::math']]],
  ['block',['block',['../namespacestan_1_1math.html#a69be3cf865daa6eca4a859f97ffaa8f7',1,'stan::math']]],
  ['bytes_5fallocated',['bytes_allocated',['../classstan_1_1math_1_1stack__alloc.html#ac72fe7b15ca3086766445e2672e0b504',1,'stan::math::stack_alloc']]]
];
